@@ -30,6 +30,7 @@ import traceback
 import sanic
 import logging
 import PirxcyPinger
+import crayons
 import json
 import sys
 import os
@@ -37,10 +38,33 @@ import asyncio
 import aiohttp
 
 from fortnitepy.ext import commands
+from sanic import Sanic
+from .endpoints import web as endpoints
 
+def cyan(string):
+  output = crayons.cyan(string)
+  return str(output)
+
+def red(string):
+  output = crayons.red(string)
+  return str(output)
+
+def green(string):
+  output = crayons.green(string)
+  return str(output)
+
+app = Sanic(__name__)
 loop = asyncio.get_event_loop()
-app = sanic.Sanic("PirxcyBot")
-logging.basicConfig(format='[PirxcyBot] [%(asctime)s] - %(message)s', datefmt='%d-%b-%y %H:%M:%S', level=logging.INFO)
+
+app.blueprint(endpoints, url_prefix="/")
+
+logger = logging.getLogger(__name__)
+logger.setLevel(logging.DEBUG)
+ch = logging.StreamHandler()
+ch.setLevel(logging.DEBUG)
+formatter = logging.Formatter(cyan('[PirxcyBot] [%(asctime)s] [%(levelname)s] - %(message)s'))
+ch.setFormatter(formatter)
+logger.addHandler(ch)
 
 def clear():
   os.system('cls || clear')
@@ -57,14 +81,14 @@ async def get_items():
   file = open("items.json", "w")
   json.dump(items, file, indent=2)
   file.close()
-  logging.info('Cached All bot Items')
+  logger.info(green('Cached All bot Items'))
   return
 
 async def get_settings():
   async with aiohttp.ClientSession() as session:
     async with session.request(
       method="GET",
-      url="https://lobbybotconfiguration.pirxcyfinal.repl.co/blacklist"
+      url="https://lobbybotconfiguration.pirxcy1942.repl.co/blacklist"
       ) as r:
           main = await r.json()
   return main
@@ -75,7 +99,7 @@ async def post_blacklist(id):
   async with aiohttp.ClientSession() as session:
     async with session.request(
       method="POST",
-      url="https://lobbybotconfiguration.pirxcyfinal.repl.co/blacklist",
+      url="https://lobbybotconfiguration.pirxcy1942.repl.co/blacklist",
       json=(blacklist)
       ) as r:
       return
@@ -109,11 +133,13 @@ def load_cosmetics():
       print("An Json Decode Error Occured While Reading items.json (Contact Pirxcy for Help)")
       sys.exit()
 
+clear()
 response = input('Enter A Valid Authorization Code: ')
+clear()
 try:
   url = PirxcyPinger.get_url(platform='replit')
 except:
-  logging.error('Invalid Platform Please Use on Replit!')
+  logger.warning(red('Invalid Platform Please Use on Replit!'))
 
 if "redirectUrl" in response:
   response = json.loads(response)
@@ -129,7 +155,9 @@ else:
     code = response.split("?code=")[1]
   else:
     code = response
-    
+
+logger.info('Proceeding To Generate Auths!')
+
 async def code_to_auths(code):
   async with aiohttp.ClientSession() as session:
     async with session.request(
@@ -154,9 +182,9 @@ async def code_to_auths(code):
     ) as r:
       data2 = await r.text()
       auths = json.loads(data2)
-    auths['created'].pop('ipAddress')         
+    auths['created'].pop('ipAddress')
+    logger.info(green('Generated Auths!'))
     return auths
-
 auths = loop.run_until_complete(code_to_auths(code))
 
 bot = commands.Bot(
@@ -165,13 +193,12 @@ bot = commands.Bot(
   auth=fortnitepy.DeviceAuth(
     device_id=auths['deviceId'],
     account_id=auths['accountId'],
-    secret=auths['secret']
+    secret=auths['secret']                                                              
   )
 )
 
-@app.route('/')
-async def index(request):
-  return sanic.response.text('Client Ready')
+def botdef():
+  return bot
 
 @bot.event
 async def event_party_invite(invite):
@@ -187,11 +214,14 @@ async def event_party_invite(invite):
   else:
     await invite.decline()
 
+server = None
+
 @bot.event
-async def event_ready():
+async def event_ready() -> None:
+  global server
   config = open_config()
   if config['owner'] == "":
-    logging.info('You Haven\'t Filled Out The Config! (Expect Errors To Occur)')
+    logger.warning(red('You Haven\'t Filled Out The Config! (Expect Errors To Occur)'))
   try:
     user = await bot.fetch_profile(config['owner'])
     if user.id in bot.friends:
@@ -204,14 +234,28 @@ async def event_ready():
   await get_items()
   await bot.set_presence(config['status']) 
   clear()
-  logging.info(f'Launched {bot.user.display_name}')
+  logger.info(green(f'Launched {bot.user.display_name}'))
   try:
     await PirxcyPinger.post(f"https://{os.environ['REPL_ID']}.id.repl.co")
-    logging.info('Uploaded URL To PirxcyPinger!')
+    logger.info(green('Uploaded URL To PirxcyPinger!'))
   except PirxcyPinger.AlreadyPinging: #if url is already submitted
-    logging.error('Already Pinging URL!')
+    logger.warning('Already Pinging URL!')
   except:
     pass
+  logger.info('Starting Server')
+  log = logging.getLogger('werkzeug')
+  log.disabled = True
+  coro = app.create_server(
+    host='0.0.0.0',
+    port=5595,
+    return_asyncio_server=True,
+    debug=False,
+    access_log=False
+  )
+  try:
+    server = await coro
+  except Exception as e:
+    logger.error(red(f'Error Starting Server {e}'))
 
 @bot.event
 async def event_party_member_join(member):
@@ -220,7 +264,7 @@ async def event_party_member_join(member):
   owners = [i for i in settings['whitelist_id']]
   owners.append(config['owner'])
   if member.id in owners:
-    logging.info(f'{member.display_name} (An Admin) Has Joined!')
+    logger.info(red(f'{member.display_name} (An Admin) Has Joined!'))
     await member.promote()
     await bot.party.send(config['join_message'])
     await bot.party.send("An Admin of This Bot Has Joined!")
@@ -229,7 +273,7 @@ async def event_party_member_join(member):
     await member.block()
     await member.kick()
   else:
-    logging.info(f'{member.display_name} Has Joined!')
+    logger.info(f'{member.display_name} Has Joined!')
     await bot.party.send(f"{config['join_message']}\nMade By Pirxcy")
     
 
@@ -239,14 +283,14 @@ async def event_friend_message(message):
   if message.author.display_name in settings['blocked_names']:
     await message.author.block()
     await message.author.kick()
-    logging.info(f'Blocked/Kicked {message.author.display_name}')
+    logger.warning(red(f'Blocked/Kicked {message.author.display_name}'))
     await bot.process_commands(message)
   elif any(word.lower() in message.content.lower() for word in settings['blacklist_keywords']):
     await post_blacklist(id=message.author.id)
-    logging.info(f'Added {message.author.display_name} to the blacklist!')
+    logger.warning(red(f'Added {message.author.display_name} to the blacklist!'))
     await bot.process_commands(message)
   else:
-    logging.info(f'[{message.author.display_name}] {message.content}')
+    logger.info(green(f'[{message.author.display_name}] {message.content}'))
     await bot.process_commands(message)
 
 @bot.event
@@ -255,14 +299,17 @@ async def event_party_message(message):
   if message.author.display_name in settings['blocked_names']:
     await message.author.block()
     await message.author.kick()
-    logging.info(f'Blocked/Kicked {message.author.display_name}')
+    logger.warning(red(f'Blocked/Kicked {message.author.display_name}'))
+    await bot.process_commands(message)
   elif any(word.lower() in message.content.lower() for word in settings['blacklist_keywords']):
     await post_blacklist(id=message.author.display_name)
     await message.author.block()
     await message.author.kick()
-    logging.info(f'Added {message.author.display_name} to the blacklist!')
+    logger.warning(red(f'Added {message.author.display_name} to the blacklist!'))
+    await bot.process_commands(message)
   else:
-    logging.info(f'[{message.author.display_name}] {message.content}')
+    logger.info(f'[{message.author.display_name}] {message.content}')
+    await bot.process_commands(message)
 
 @bot.command()
 async def hello(ctx):
@@ -270,7 +317,6 @@ async def hello(ctx):
 
 @bot.command()
 async def skin(ctx, *, content = None):
-  logging.info(f'{ctx.author} Excecuted The Skin command')
   try:
     cosmetics = load_cosmetics()
     if content is None:
@@ -322,7 +368,6 @@ async def skin(ctx, *, content = None):
 
 @bot.command()
 async def emote(ctx, *, content = None):
-  logging.info(f'{ctx.author} Excecuted The Emote command')
   try:
     cosmetics = load_cosmetics()
     if content is None:
@@ -377,7 +422,6 @@ async def emote(ctx, *, content = None):
   
 @bot.command()
 async def backpack(ctx, *, content = None):
-  logging.info(f'{ctx.author} Excecuted The Backpack command')
   try:
     cosmetics = load_cosmetics()
     if content is None:
@@ -429,7 +473,6 @@ async def backpack(ctx, *, content = None):
 
 @bot.command()
 async def pickaxe(ctx, *, content = None):
-  logging.info(f'{ctx.author} Excecuted The Pickaxe command')
   try:
     cosmetics = load_cosmetics()
     if content is None:
@@ -484,7 +527,6 @@ async def pickaxe(ctx, *, content = None):
 
 @bot.command()
 async def pinkghoul(ctx):
-  logging.info(f'{ctx.author} Excecuted pinkghoul')
   await bot.party.me.set_outfit(
     asset='CID_029_Athena_Commando_F_Halloween',
     variants=bot.party.me.create_variants(
@@ -495,7 +537,7 @@ async def pinkghoul(ctx):
 
 @bot.command()
 async def checkeredrenegade(ctx):
-  logging.info(f'{ctx.author} Excecuted checkeredrenegade')
+  logger.info(f'{ctx.author} Excecuted checkeredrenegade')
   await bot.party.me.set_outfit(
     asset='CID_028_Athena_Commando_F',
     variants=bot.party.me.create_variants(
@@ -506,7 +548,6 @@ async def checkeredrenegade(ctx):
 
 @bot.command()
 async def purpleportal(ctx):
-  logging.info(f'{ctx.author} Excecuted purpleportal')
   await bot.party.me.set_backpack(
     asset='BID_105_GhostPortal',
     variants=bot.party.me.create_variants(
@@ -519,7 +560,7 @@ async def purpleportal(ctx):
 
 @bot.command()
 async def purpleskull(ctx):
-  logging.info(f'{ctx.author} Excecuted purpleskull')
+  logger.info(f'{ctx.author} Excecuted purpleskull')
   await bot.party.me.set_outfit(
     asset='CID_030_Athena_Commando_M_Halloween',
     variants=bot.party.me.create_variants(
@@ -530,7 +571,6 @@ async def purpleskull(ctx):
 
 @bot.command()
 async def goldpeely(ctx):
-  logging.info(f'{ctx.author} Excecuted goldpeely')
   await bot.party.me.set_outfit(
     asset='CID_701_Athena_Commando_M_BananaAgent',
     variants=bot.party.me.create_variants(
@@ -545,7 +585,7 @@ async def goldpeely(ctx):
 
 @bot.command()
 async def hatlessrecon(ctx):
-  logging.info(f'{ctx.author} Excecuted hatlessrecon')
+  logger.info(f'{ctx.author} Excecuted hatlessrecon')
   await bot.party.me.set_outfit(
     asset='CID_022_Athena_Commando_F',
     variants=bot.party.me.create_variants(
@@ -556,7 +596,6 @@ async def hatlessrecon(ctx):
 
 @bot.command()
 async def hologram(ctx):
-  logging.info(f'{ctx.author} Excecuted hologram')
   await bot.party.me.set_outfit(
     asset='CID_VIP_Athena_Commando_M_GalileoGondola_SG'
   )
@@ -564,31 +603,28 @@ async def hologram(ctx):
 
 @bot.command()
 async def ready(ctx):
-  logging.info(f'{ctx.author} Excecuted ready')
+  logger.info(f'{ctx.author} Excecuted ready')
   await bot.party.me.set_ready(fortnitepy.ReadyState.READY)
   await ctx.send('Bot is Ready!')
 
 @bot.command()
 async def unready(ctx):
-  logging.info(f'{ctx.author} Excecuted unready')
   await bot.party.me.set_ready(fortnitepy.ReadyState.NOT_READY)
   await ctx.send('Bot is Unready!')
 
 @bot.command()
 async def sitin(ctx):
-  logging.info(f'{ctx.author} Excecuted sitin')
+  logger.info(f'{ctx.author} Excecuted sitin')
   await bot.party.me.set_ready(fortnitepy.ReadyState.NOT_READY)
   await ctx.send('Sitting in')
 
 @bot.command()
 async def sitout(ctx):
-  logging.info(f'{ctx.author} Excecuted sitout')
   await bot.party.me.set_ready(fortnitepy.ReadyState.SITTING_OUT)
   await ctx.send('Sitting out')
 
 @bot.command()
 async def tier(ctx, tier = None):
-  logging.info(f'{ctx.author} Excecuted tier')
   if tier is None:
     await ctx.send('Try !tier 1942') 
   else:
@@ -600,7 +636,6 @@ async def tier(ctx, tier = None):
 
 @bot.command()
 async def level(ctx, level = None):
-  logging.info(f'{ctx.author} Excecuted level')
   if level is None:
     await ctx.send(f'Try !level 1942')
   else:
@@ -610,7 +645,7 @@ async def level(ctx, level = None):
 @bot.command()
 @is_admin()
 async def say(ctx, *, message = None):
-  logging.info(f'{ctx.author} Excecuted say')
+  logger.info(f'{ctx.author} Excecuted say')
   if message is not None:
     await bot.party.send(message)
     await ctx.send(f'Message Sent.')
@@ -655,7 +690,5 @@ async def join(ctx, *, member = None):
   except AttributeError:
       await ctx.send("I can not join that party. Are you sure I have them friended?")
 
-
-loop.create_task(app.create_server(host='0.0.0.0', port=8080, return_asyncio_server=True,  access_log=True))
-loop.create_task(bot.start())
-loop.run_forever()
\ No newline at end of file
+def run(ip = str, port = int):
+  bot.run()
